@@ -3,10 +3,9 @@
  * JCommon-Serializer : a free serialization framework
  * ===================================================
  *
- * Project Info:  http://www.jfree.org/jfreereport/jcommon-serializer/
- * Project Lead:  Thomas Morgner;
+ * Project Info:  http://reporting.pentaho.org/jcommon-serializer/
  *
- * (C) Copyright 2006, by Object Refinery Limited and Pentaho Corporation.
+ * (C) Copyright 2006-2008, by Object Refinery Limited, Pentaho Corporation and Contributors.
  *
  * This library is free software; you can redistribute it and/or modify it under the terms
  * of the GNU Lesser General Public License as published by the Free Software Foundation;
@@ -24,35 +23,20 @@
  * in the United States and other countries.]
  *
  * ------------
- * JCommonSerializerInfo.java
+ * JCommonSerializerInfo
  * ------------
- * (C) Copyright 2006, by Object Refinery Limited and Pentaho Corporation.
- *
- * Original Author:  Thomas Morgner;
- * Contributor(s):   -;
- *
- * $Id: JCommonSerializerInfo.java 3093 2007-08-01 19:34:59Z tmorgner $
- *
- * Changes
- * -------
- *
- *
  */
 
 package org.jfree.serializer;
 
-import java.util.Arrays;
-
-import org.jfree.ui.about.ProjectInfo;
-import org.jfree.ui.about.Contributor;
-import org.jfree.JCommonInfo;
+import org.pentaho.reporting.libraries.base.versioning.ProjectInformation;
 
 /**
  * Creation-Date: 23.10.2005, 18:49:39
  *
  * @author Thomas Morgner
  */
-public class JCommonSerializerInfo extends ProjectInfo
+public class JCommonSerializerInfo extends ProjectInformation
 {
   /**
    * The info singleton.
@@ -69,6 +53,7 @@ public class JCommonSerializerInfo extends ProjectInfo
     if (singleton == null)
     {
       singleton = new JCommonSerializerInfo();
+      singleton.initialize();
     }
     return singleton;
   }
@@ -79,20 +64,18 @@ public class JCommonSerializerInfo extends ProjectInfo
    */
   private JCommonSerializerInfo()
   {
-    final JCommonInfo info = JCommonInfo.getInstance();
+    super("jcommon-serializer", "JCommon-Serializer");
+  }
 
-    setName("JCommon-Serializer");
-    setVersion("0.2.0");
+  /**
+   * Second step of the initialization.
+   */
+  private void initialize() 
+  {
     setInfo("http://reporting.pentaho.org/jcommon-serializer/");
     setCopyright("(C)opyright 2006-2007, by Pentaho Corporation, Object Refinery Limited and Contributors");
 
-    setLicenceName(info.getLicenceName());
-    setLicenceText(info.getLicenceText());
-
-    setContributors(Arrays.asList(new Contributor[]{
-        new Contributor("David Gilbert", "david.gilbert@object-refinery.com"),
-        new Contributor("Thomas Morgner", "tmorgner@pentaho.org"),
-    }));
+    setLicenseName("LGPL");
 
     setBootClass(JCommonSerializerBoot.class.getName());
   }
