@@ -3,10 +3,9 @@
  * JCommon-Serializer : a free serialization framework
  * ===================================================
  *
- * Project Info:  http://www.jfree.org/jfreereport/jcommon-serializer/
- * Project Lead:  Thomas Morgner;
+ * Project Info:  http://reporting.pentaho.org/jcommon-serializer/
  *
- * (C) Copyright 2006, by Object Refinery Limited and Pentaho Corporation.
+ * (C) Copyright 2006-2008, by Object Refinery Limited, Pentaho Corporation and Contributors.
  *
  * This library is free software; you can redistribute it and/or modify it under the terms
  * of the GNU Lesser General Public License as published by the Free Software Foundation;
@@ -24,30 +23,17 @@
  * in the United States and other countries.]
  *
  * ------------
- * Line2DSerializer.java
+ * Line2DSerializer
  * ------------
- * (C) Copyright 2006, by Object Refinery Limited and Pentaho Corporation.
- *
- * Original Author:  Thomas Morgner;
- * Contributor(s):   -;
- *
- * $Id: Line2DSerializer.java 1776 2006-04-17 16:03:24Z taqua $
- *
- * Changes
- * -------
- *
- *
  */
 
 package org.jfree.serializer.methods;
 
-import java.awt.Shape;
 import java.awt.geom.Line2D;
 import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 
-import org.jfree.io.SerialUtilities;
 import org.jfree.serializer.SerializeMethod;
 
 /**
